==> vpn-user-portal-3.4.1.tgz: vpn-user-portal/locale/ca-ES.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Actives (Max #Disponibles) Connexions',
    '#Connections in 5 minute intervals' => '#Connexions en intervals de 5 minuts',
    '#Unique Guest Users' => '#Usuaris convidats únics',
    '#Unique Users' => '#Usuaris únics',
    '#Unique users and max #connections per day' => 'Usuaris únics i max #connexions per dia',
    'ACL Permission List' => 'Llista de permissos ACL',
    'Account' => 'Compte',
    'Active' => 'Actiu',
    'Active Configurations' => 'Connexions Actives',
    'Advanced' => 'Avançat',
    'Aggregated' => 'Agregat',
    'All' => 'Tots',
    'An application attempts to establish a VPN connection.' => 'Una aplicació està intentant establir una connexió VPN.',
    'An error occurred.' => 'Ha ocorregut un error.',
    'Application Usage' => 'Ús de l\'aplicació',
    'Approve' => 'Aprovar',
    'Approve Application' => 'Aprovar Aplicació',
    'Authentication Data' => 'Dades de l\'autenticació',
    'Authorized Applications' => 'Aplicacions Autoritzades',
    'Authorized On' => 'Autoritzat el',
    'Available Profiles' => 'Perfils Disponibles',
    'Block LAN' => 'Bloqueig de LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Ús de CPU:',
    'Change Password' => 'Canviar Contrasenya',
    'Configurations' => 'Configuracions',
    'Confirm' => 'Confirmar',
    'Connected' => 'Connectat',
    'Connections' => 'Connexions',
    'Created On' => 'Creat el',
    'Current Password' => 'Contrasenya Actual',
    'Current Password not correct!' => 'Contrasenya Actual Incorrecta!',
    'Currently there are no clients connected to this profile.' => 'Actualment no hi ha cap client connectat a aquest perfil',
    //'DNS Search Domain(s)' => '',
    'DNS Server(s)' => 'Servidor(s) DNS',
    'Danger Zone' => 'Zona Perillosa',
    'Date/Time' => 'Data/Hora',
    'Default Gateway' => 'Gateway Per Defecte',
    'Delete' => 'Esborrar',
    'Delete Account' => 'Esborrar Compte',
    'Delete Account Data' => 'Esborrar Dades del Compte',
    'Disable Account' => 'Deshabilitar Compte',
    'Disabled' => 'Deshabilitat',
    'Disconnected' => 'Desconnectat',
    'Distribution of unique users over the VPN applications.' => 'Distribució d\'usuaris únics per aplicacions VPN.',
    'Download' => 'Descarregar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'No està permesa la descarrega de configuracions VPN. Useu una aplicació VPN',
    'Enable Account' => 'Activar Compte',
    //'Error' => '',
    'Excluded Route(s)' => 'Excloure Rutes',
    'Expires On' => 'Expira en',
    'Export (CSV)' => 'Exportar (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Troba l\'identificador d\'usuari que ha emprat una adreça IPv4 o IPv6 en un moment determinat',
    //'Fingerprint' => '',
    'Here you can change the password for your account.' => 'Ací podràs canviar la contrasenya del teu compte',
    'Home' => 'Inici',
    //'Hostname' => '',
    'IP Address' => 'Adreça IP',
    //'IPs' => '',
    //'IPv4 Prefix' => '',
    //'IPv6 Prefix' => '',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importar o copia-i-enganxa aquesta configuració en l\'aplicació de WireGuard',
    //'Info' => '',
    //'Issues' => '',
    //'Live' => '',
    //'Log' => '',
    //'MTU' => '',
    'Max #Connections' => 'Max #Connexions',
    'More' => 'Més Info',
    'N/A' => 'N/D',
    'Name' => 'Nom',
    'New Configuration' => 'Nova Configuració',
    'New Password' => 'Nova Contrasenya',
    'New Password (confirm)' => 'Nova Contrasenya (Confirmar)',
    'New Password and New Password (confirm) MUST match!' => 'La contrasenya nova i la confirmació han de coincidir!',
    //'No Permission(s)' => '',
    'No VPN profiles are available for your account.' => 'No hi ha cap perfil VPN per a aquest compte',
    'Node URL' => 'URL del Node(s)',
    //'Node(s)' => '',
    //'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenció d\'un nou arxiu de configuració VPN per a emprar en el vostre Client VPN.',
    //'Offered Ports' => '',
    //'Offline' => '',
    //'Online' => '',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Solament aprova ',
    //'OpenVPN' => '',
    'OpenVPN Server Log' => 'Servidor de Log OpenVPN',
    'Password' => 'Contrasenya',
    'Permissions' => 'Permissos',
    'Please sign in with your username and password.' => 'Identifiqueu-vos amb usuari i contrasenya',
    //'Port' => '',
    //'Ports' => '',
    'Prefer connecting over TCP (OpenVPN)' => 'Connexió per TCP preferida (OpenVPN)',
    'Preferred Protocol' => 'Protocol Preferit',
    'Profile' => 'Perfil',
    'Profile Default' => 'Perfil Per Defecte',
    'Profile Usage' => 'Ús dels Perfils',
    'Profile(s)' => 'Perfil(s)',
    'Public Key' => 'Clau Pública',
    'Results' => 'Resultat',
    'Revoke' => 'Revocar',
    'Route(s)' => 'Rutes',
    'Search' => 'Cercar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Seleccioneu un perfil i escolliu un nom, ie: mòbil',
    'Server' => 'Servidor',
    'Sign In' => 'Accedir',
    'Sign Out' => 'Eixir',
    'Stats' => 'Estadístiques',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>Data/Hora</em> HA d\'estar en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Els camps <em>Data/Hora</em> accepten dates amb el format <code>Y-m-d H:i:s</code>, i.e. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Les credencials aportades no són correctes',
    'The list of applications you authorized to create a VPN connection.' => 'La llista de les aplicacions autoritzades per a crear una connexió VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Nombre màxim de clients VPN connectats simultàniament en un moment en concret de la setmana passada',
    'The most recent VPN connections with this account.' => 'Últimes connexións VPN amb aquest compte d\'usuari',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Nombre màxim actual de clients VPN connectats, i el màxim nombre de possibles clients basats el l\'espai IP disponible per a aquest perfil',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Nombre d\'usuaris convidats únics connectats al servei de la VPN la darrera setmana',
    'The number of unique users connecting to the VPN service in the last week' => 'Nombre d\'usuaris únics connectats al servei de la VPN la darrera setmana',
    'The table below shows the per profile VPN usage over the last week.' => 'La taula de baix mostra l\'ús de la VPN per cada perfil per a la darrera setmana.',
    'There are no results matching your criteria.' => 'No hi ha cap resultat que coincidisca amb el teu criteri de cerca.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Aquest servidor empra una font d\'autenticació externa. Esborrar les dades del compte no impediran que l\'usuari s\'autentique de nou!',
    'This user does not have any active configurations.' => 'Aquest usuari no té cap configuració activa.',
    'This user does not have any connections.' => 'Aquest usuari no te cap connexió.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Per a impedir ca aplicacions malicioses estableisquen secretament una connexió VPN en compte teu, caldrà que primerament aproves explicitament aquesta aplicació.',
    'Use Protocol' => 'Emprar protocol',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Empra l\'aplicació WireGuard del teu dispositiu mòbil per a escanejar aquest codi QR.',
    'User ID' => 'ID Usuari',
    'Username' => 'Usuari',
    'Users' => 'Usuaris',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versió',
    'Welcome to this VPN service!' => 'Benvingut a aquest servei VPN',
    'Why is this necessary?' => 'Per què això és necessari?',
    //'WireGuard' => '',
    'WireGuard Configuration' => 'Configuració del WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Podeu descarregar les estadístiques detallades d\'ús de la VPN a sota.',
    'You cannot manage your own user account.' => 'No pots gestionar el teu compte d\'usuari',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Has arribat al màxim nombre de connexions VPN permeses. Esborreu algunes abans.',
    'Your account does not have access to any VPN profile.' => 'El teu compte d\'usuari no te accés a cap perfil de VPN',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'La nova configuració expirarà el %expiryDate%. Cal obtenir una nova configuració una vegada aquesta haja expirat!',
];

==> vpn-user-portal-3.5.6.tgz: vpn-user-portal/locale/ca-ES.php <==
<?php

declare(strict_types=1);

/*
 * eduVPN - End-user friendly VPN.
 *
 * Copyright: 2014-2023, The Commons Conservancy eduVPN Programme
 * SPDX-License-Identifier: AGPL-3.0+
 */

return [
    '#Active (Max #Available) Connections' => '#Actives (Max #Disponibles) Connexions',
    '#Connections in 5 minute intervals' => '#Connexions en intervals de 5 minuts',
    '#Unique Guest Users' => '#Usuaris convidats únics',
    '#Unique Users' => '#Usuaris únics',
    '#Unique users and max #connections per day' => 'Usuaris únics i max #connexions per dia',
    'ACL Permission List' => 'Llista de permissos ACL',
    'Account' => 'Compte',
    'Active' => 'Actiu',
    'Active Configurations' => 'Connexions Actives',
    'Aggregated' => 'Agregat',
    'All' => 'Tots',
    'An application attempts to establish a VPN connection.' => 'Una aplicació està intentant establir una connexió VPN.',
    'An error occurred.' => 'Ha ocorregut un error.',
    'Application Usage' => 'Ús de l\'aplicació',
    'Approve' => 'Aprovar',
    'Approve Application' => 'Aprovar Aplicació',
    'Authentication Data' => 'Dades de l\'autenticació',
    'Authorized Applications' => 'Aplicacions Autoritzades',
    'Authorized On' => 'Autoritzat el',
    'Available Profiles' => 'Perfils Disponibles',
    'Block LAN' => 'Bloqueig de LAN',
    'CA' => 'CA',
    'CPU Usage:' => 'Ús de CPU:',
    'Change Password' => 'Canviar Contrasenya',
    'Configurations' => 'Configuracions',
    'Confirm' => 'Confirmar',
    'Connected' => 'Connectat',
    'Connections' => 'Connexions',
    'Created On' => 'Creat el',
    'Current Password' => 'Contrasenya Actual',
    'Current Password not correct!' => 'Contrasenya Actual Incorrecta!',
    'Currently there are no clients connected to this profile.' => 'Actualment no hi ha cap client connectat a aquest perfil',
    //'DNS Search Domain(s)' => '',
    'DNS Server(s)' => 'Servidor(s) DNS',
    'Danger Zone' => 'Zona Perillosa',
    'Date/Time' => 'Data/Hora',
    'Default Gateway' => 'Gateway Per Defecte',
    'Delete' => 'Esborrar',
    'Delete Account' => 'Esborrar Compte',
    'Delete Account Data' => 'Esborrar Dades del Compte',
    'Disable Account' => 'Deshabilitar Compte',
    'Disabled' => 'Deshabilitat',
    'Disconnected' => 'Desconnectat',
    'Distribution of unique users over the VPN applications.' => 'Distribució d\'usuaris únics per aplicacions VPN.',
    'Download' => 'Descarregar',
    'Downloading VPN configurations is not allowed. Please use a VPN application.' => 'No està permesa la descarrega de configuracions VPN. Useu una aplicació VPN',
    'Enable Account' => 'Activar Compte',
    //'Error' => '',
    'Excluded Route(s)' => 'Excloure Rutes',
    'Expires On' => 'Expira en',
    'Export (CSV)' => 'Exportar (CSV)',
    'Find the user identifier that used an IPv4 or IPv6 address at a particular point in time.' => 'Troba l\'identificador d\'usuari que ha emprat una adreça IPv4 o IPv6 en un moment determinat',
    //'Fingerprint' => '',
    'Here you can change the password for your account.' => 'Ací podràs canviar la contrasenya del teu compte',
    'Home' => 'Inici',
    //'Hostname' => '',
    'IP Address' => 'Adreça IP',
    //'IPs' => '',
    //'IPv4 Prefix' => '',
    //'IPv6 Prefix' => '',
    'Import or copy/paste this configuration to your WireGuard application.' => 'Importar o copia-i-enganxa aquesta configuració en l\'aplicació de WireGuard',
    //'Info' => '',
    //'Issues' => '',
    //'Live' => '',
    //'Log' => '',
    //'MTU' => '',
    'Max #Connections' => 'Max #Connexions',
    'More' => 'Més Info',
    'N/A' => 'N/D',
    'Name' => 'Nom',
    'New Configuration' => 'Nova Configuració',
    'New Password' => 'Nova Contrasenya',
    'New Password (confirm)' => 'Nova Contrasenya (Confirmar)',
    'New Password and New Password (confirm) MUST match!' => 'La contrasenya nova i la confirmació han de coincidir!',
    //'No Permission(s)' => '',
    'No VPN profiles are available for your account.' => 'No hi ha cap perfil VPN per a aquest compte',
    'Node URL' => 'URL del Node(s)',
    //'Node(s)' => '',
    //'OAuth' => '',
    'Obtain a new VPN configuration file for use in your VPN client.' => 'Obtenció d\'un nou arxiu de configuració VPN per a emprar en el vostre Client VPN.',
    //'Offered Ports' => '',
    //'Offline' => '',
    //'Online' => '',
    'Only approve this when you are trying to establish a VPN connection with this application!' => 'Solament aprova ',
    //'OpenVPN' => '',
    //'OpenVPN (Prefer TCP)' => '',
    //'OpenVPN (Prefer UDP)' => '',
    'OpenVPN Server Log' => 'Servidor de Log OpenVPN',
    'Password' => 'Contrasenya',
    'Permissions' => 'Permissos',
    'Please sign in with your username and password.' => 'Identifiqueu-vos amb usuari i contrasenya',
    //'Port' => '',
    //'Ports' => '',
    'Preferred Protocol' => 'Protocol Preferit',
    'Profile' => 'Perfil',
    //'Profile ID' => '',
    'Profile Usage' => 'Ús dels Perfils',
    'Profile(s)' => 'Perfil(s)',
    'Public Key' => 'Clau Pública',
    //'Refresh' => '',
    'Results' => 'Resultat',
    'Revoke' => 'Revocar',
    'Route(s)' => 'Rutes',
    'Search' => 'Cercar',
    'Select a profile and choose a name, e.g. "Phone".' => 'Seleccioneu un perfil i escolliu un nom, ie: mòbil',
    'Server' => 'Servidor',
    'Sign In' => 'Accedir',
    'Sign Out' => 'Eixir',
    'Stats' => 'Estadístiques',
    'The <em>Date/Time</em> MUST be in UTC.' => 'La <em>Data/Hora</em> HA d\'estar en UTC.',
    'The <em>Date/Time</em> field accepts dates of the format <code>Y-m-d H:i:s</code>, e.g. <code>2019-01-01 08:00:00</code>.' => 'Els camps <em>Data/Hora</em> accepten dates amb el format <code>Y-m-d H:i:s</code>, i.e. <code>2019-01-01 08:00:00</code>.',
    'The credentials you provided were not correct.' => 'Les credencials aportades no són correctes',
    'The list of applications you authorized to create a VPN connection.' => 'La llista de les aplicacions autoritzades per a crear una connexió VPN.',
    'The maximum number of simultaneously connected VPN clients at a particular moment in time over the last week' => 'Nombre màxim de clients VPN connectats simultàniament en un moment en concret de la setmana passada',
    'The most recent VPN connections with this account.' => 'Últimes connexións VPN amb aquest compte d\'usuari',
    'The number of currently connected VPN clients, and the maximum possible number of connected VPN clients based on available IP-space for this profile.' => 'Nombre màxim actual de clients VPN connectats, i el màxim nombre de possibles clients basats el l\'espai IP disponible per a aquest perfil',
    'The number of unique guest users connecting to the VPN service in the last week' => 'Nombre d\'usuaris convidats únics connectats al servei de la VPN la darrera setmana',
    'The number of unique users connecting to the VPN service in the last week' => 'Nombre d\'usuaris únics connectats al servei de la VPN la darrera setmana',
    'The table below shows the per profile VPN usage over the last week.' => 'La taula de baix mostra l\'ús de la VPN per cada perfil per a la darrera setmana.',
    'There are no results matching your criteria.' => 'No hi ha cap resultat que coincidisca amb el teu criteri de cerca.',
    'This server uses an external authentication source. Deleting the account data will not prevent the user from authenticating (again)!' => 'Aquest servidor empra una font d\'autenticació externa. Esborrar les dades del compte no impediran que l\'usuari s\'autentique de nou!',
    'This user does not have any active configurations.' => 'Aquest usuari no té cap configuració activa.',
    'This user does not have any connections.' => 'Aquest usuari no te cap connexió.',
    'To prevent malicious applications from secretly establishing a VPN connection on your behalf, you have to explicitly approve this application first.' => 'Per a impedir ca aplicacions malicioses estableisquen secretament una connexió VPN en compte teu, caldrà que primerament aproves explicitament aquesta aplicació.',
    'Use the WireGuard app on your mobile device to scan this QR code.' => 'Empra l\'aplicació WireGuard del teu dispositiu mòbil per a escanejar aquest codi QR.',
    'User ID' => 'ID Usuari',
    'Username' => 'Usuari',
    'Users' => 'Usuaris',
    'VPN Portal' => 'Portal VPN',
    'Version' => 'Versió',
    'Welcome to this VPN service!' => 'Benvingut a aquest servei VPN',
    'Why is this necessary?' => 'Per què això és necessari?',
    //'WireGuard' => '',
    'WireGuard Configuration' => 'Configuració del WireGuard',
    'You can download the detailed VPN usage statistics below.' => 'Podeu descarregar les estadístiques detallades d\'ús de la VPN a sota.',
    'You cannot manage your own user account.' => 'No pots gestionar el teu compte d\'usuari',
    'You have reached the maximum number of allowed active VPN configurations. Delete some first.' => 'Has arribat al màxim nombre de connexions VPN permeses. Esborreu algunes abans.',
    'Your account does not have access to any VPN profile.' => 'El teu compte d\'usuari no te accés a cap perfil de VPN',
    'Your new configuration will expire on %expiryDate%. Come back here to obtain a new configuration after expiry!' => 'La nova configuració expirarà el %expiryDate%. Cal obtenir una nova configuració una vegada aquesta haja expirat!',
];
